==> react-native-digitcamera-1.46.0.tgz: package/src/Screens/SilentUpload/NotificationsConfig.js <==
const BASE_NOTIFICATION_COFIG = {
  taskName: "baseName",
  taskTitle: "baseTitle",
  taskDesc: "baseDescription",
  taskIcon: {
    name: "ic_launcher",
    type: "mipmap",
  },
  color: "#DDDDDD",
  linkingURI: "uat-DigitMotorInsurance.godigit.com/SilentUploads",
  progressBar: {
    max: 100,
    value: 0,
    indeterminate: false,
  },
};

const FOREGROUND_VIDEO_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  taskName: "SilentVideoUpload",
  taskTitle: "Uploading Video",
  taskDesc:
    "We are uploading your documents offline so that your process finish quickly and you can continue using your phone",
};

const FOREGROUND_IMAGE_UPLOAD = {
  taskName: "SilentImageUpload",
  taskTitle: "Uploading Images",
  taskDesc:
    "We are uploading your documents in background so that your process finish quickly and you can continue using your phone",
};

const BG_KILLED_VIDEO_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "SilentVideoUpload",
  taskTitle: "Uploading Video",
  taskDesc: "",
  // We can add progressBar object in runtime here
};

const BG_KILLED_IMAGE_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  taskName: "SilentImageUpload",
  taskTitle: "Uploading Images",
  taskDesc: "",
  //we can add progressBar Object in runtime here
};

const BEFORE_SUBMIT_PI = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "BeforeSubmitPI",
  taskTitle: "Finalizing",
  taskDesc: "Please wait while we finish the final process.",
};

const AFTER_SUBMIT_PI_SUCCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterSubmitPISuccess",
  taskTitle: "Documents Received",
  taskDesc: "Thank you for waiting, we have received your documents.",
};

const AFTER_SUBMIT_PI_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterSubmitPIFailure",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong",
};

const BEFORE_DOCUMENT_LAST = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "BeforeDocumentLast",
  taskTitle: "Finalizing",
  taskDesc: "Please wait while we finish the final process.",
};

const AFTER_DOCUMENT_LAST_SUCCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterDocumentLastSuccess",
  taskTitle: "Documents Received",
  taskDesc: "Thank you for waiting, we have received your documents.",
};

const AFTER_DOCUMENT_LAST_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterDocumentLastFailre",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong",
};

const BG_KILLED_UPLOAD_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong we could not upload your documents",
};

const BG_KILLED_NETWORK_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Oops No Internet!",
  taskDesc: "We will upload your documents once there is internet",
};

const BG_KILLED_NETWORK_ACCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Internet Accessible",
  taskDesc: "We will upload the files now",
};

const getCustomConfig = ({ tastName, taskTitle, taskDesc }) => {
  return {
    ...BASE_NOTIFICATION_COFIG,
    tastName,
    taskTitle,
    taskDesc,
  };
};

export default {
  FOREGROUND_IMAGE_UPLOAD,
  FOREGROUND_VIDEO_UPLOAD,
  BG_KILLED_IMAGE_UPLOAD,
  BG_KILLED_VIDEO_UPLOAD,
  BEFORE_DOCUMENT_LAST,
  AFTER_DOCUMENT_LAST_SUCCESS,
  AFTER_DOCUMENT_LAST_FAILURE,
  BEFORE_SUBMIT_PI,
  AFTER_SUBMIT_PI_SUCCESS,
  AFTER_SUBMIT_PI_FAILURE,
  BG_KILLED_UPLOAD_FAILURE,
  BG_KILLED_NETWORK_FAILURE,
  BG_KILLED_NETWORK_ACCESS,
  getCustomConfig,
};

==> react-native-digitcamera-1.47.1.tgz: package/src/Screens/SilentUpload/NotificationsConfig.js <==
const BASE_NOTIFICATION_COFIG = {
  taskName: "baseName",
  taskTitle: "baseTitle",
  taskDesc: "baseDescription",
  taskIcon: {
    name: "ic_launcher",
    type: "mipmap",
  },
  color: "#DDDDDD",
  linkingURI: "uat-DigitMotorInsurance.godigit.com/SilentUploads",
  progressBar: {
    max: 100,
    value: 0,
    indeterminate: false,
  },
};

const FOREGROUND_VIDEO_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  taskName: "SilentVideoUpload",
  taskTitle: "Uploading Video",
  taskDesc:
    "We are uploading your documents offline so that your process finish quickly and you can continue using your phone",
};

const FOREGROUND_IMAGE_UPLOAD = {
  taskName: "SilentImageUpload",
  taskTitle: "Uploading Images",
  taskDesc:
    "We are uploading your documents in background so that your process finish quickly and you can continue using your phone",
};

const BG_KILLED_VIDEO_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "SilentVideoUpload",
  taskTitle: "Uploading Video",
  taskDesc: "",
  // We can add progressBar object in runtime here
};

const BG_KILLED_IMAGE_UPLOAD = {
  ...BASE_NOTIFICATION_COFIG,
  taskName: "SilentImageUpload",
  taskTitle: "Uploading Images",
  taskDesc: "",
  //we can add progressBar Object in runtime here
};

const BG_KILLED_WAITING_FOR_UPLOADS = {
  ...BASE_NOTIFICATION_COFIG,
  taskName: "SilentWaitingForUploads",
  taskTitle: "Background Upload",
  taskDesc: "We will upload the photos as soon as you capture them.",
  //we can add progressBar Object in runtime here
};

const BEFORE_SUBMIT_PI = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "BeforeSubmitPI",
  taskTitle: "Finalizing",
  taskDesc: "Please wait while we finish the final process.",
};

const AFTER_SUBMIT_PI_SUCCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterSubmitPISuccess",
  taskTitle: "Documents Received",
  taskDesc: "Thank you for waiting, we have received your documents.",
};

const AFTER_SUBMIT_PI_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterSubmitPIFailure",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong",
};

const BEFORE_DOCUMENT_LAST = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "BeforeDocumentLast",
  taskTitle: "Finalizing",
  taskDesc: "Please wait while we finish the final process.",
};

const AFTER_DOCUMENT_LAST_SUCCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterDocumentLastSuccess",
  taskTitle: "Documents Received",
  taskDesc: "Thank you for waiting, we have received your documents.",
};

const AFTER_DOCUMENT_LAST_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "AfterDocumentLastFailre",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong",
};

const BG_KILLED_UPLOAD_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Oops!",
  taskDesc: "Something went wrong we could not upload your documents",
};

const BG_KILLED_NETWORK_FAILURE = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Oops No Internet!",
  taskDesc: "We will upload your documents once there is internet",
};

const BG_KILLED_NETWORK_ACCESS = {
  ...BASE_NOTIFICATION_COFIG,
  tastName: "UploadFailure",
  taskTitle: "Internet Accessible",
  taskDesc: "We can upload the files now",
};

const getCustomConfig = ({ taskName, taskTitle, taskDesc }) => {
  return {
    ...BASE_NOTIFICATION_COFIG,
    taskDesc,
    taskTitle,
    taskName,
  };
};

export default {
  FOREGROUND_IMAGE_UPLOAD,
  FOREGROUND_VIDEO_UPLOAD,
  BG_KILLED_IMAGE_UPLOAD,
  BG_KILLED_VIDEO_UPLOAD,
  BEFORE_DOCUMENT_LAST,
  AFTER_DOCUMENT_LAST_SUCCESS,
  AFTER_DOCUMENT_LAST_FAILURE,
  BEFORE_SUBMIT_PI,
  AFTER_SUBMIT_PI_SUCCESS,
  AFTER_SUBMIT_PI_FAILURE,
  BG_KILLED_UPLOAD_FAILURE,
  BG_KILLED_NETWORK_FAILURE,
  BG_KILLED_NETWORK_ACCESS,
  BG_KILLED_WAITING_FOR_UPLOADS,
  getCustomConfig,
};
